# This file has been generated


build_system = 'AppVeyor'
build_id = '36409541'
build_number = '580'
build_version = '1.0.580'
job_id = '4kfkeghx3pknbur1'
job_url = 'https://ci.appveyor.com/project/KyleAltendorf/stlib/build/job/4kfkeghx3pknbur1'
