# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'filesview.ui'
#
# Created by: PyQt5 UI code generator 5.13.0
#
# WARNING! All changes made in this file will be lost!


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_Form(object):
    def setupUi(self, Form):
        Form.setObjectName("Form")
        Form.resize(1000, 600)
        Form.setMaximumSize(QtCore.QSize(160000, 160000))
        self.gridLayout_2 = QtWidgets.QGridLayout(Form)
        self.gridLayout_2.setContentsMargins(0, 0, 0, 0)
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.gridLayout = QtWidgets.QGridLayout()
        self.gridLayout.setContentsMargins(8, 8, 8, 8)
        self.gridLayout.setObjectName("gridLayout")
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.verticalLayout_3 = QtWidgets.QVBoxLayout()
        self.verticalLayout_3.setObjectName("verticalLayout_3")
        self.formLayout = QtWidgets.QFormLayout()
        self.formLayout.setSizeConstraint(QtWidgets.QLayout.SetDefaultConstraint)
        self.formLayout.setFieldGrowthPolicy(QtWidgets.QFormLayout.AllNonFixedFieldsGrow)
        self.formLayout.setLabelAlignment(QtCore.Qt.AlignBottom|QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing)
        self.formLayout.setFormAlignment(QtCore.Qt.AlignHCenter|QtCore.Qt.AlignTop)
        self.formLayout.setObjectName("formLayout")
        self.label_1 = QtWidgets.QLabel(Form)
        self.label_1.setObjectName("label_1")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.label_1)
        self.filename = QtWidgets.QLineEdit(Form)
        self.filename.setEnabled(True)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.filename.sizePolicy().hasHeightForWidth())
        self.filename.setSizePolicy(sizePolicy)
        self.filename.setCursor(QtGui.QCursor(QtCore.Qt.ArrowCursor))
        self.filename.setReadOnly(True)
        self.filename.setObjectName("filename")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.filename)
        self.label_0 = QtWidgets.QLabel(Form)
        self.label_0.setObjectName("label_0")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.label_0)
        self.version = QtWidgets.QLineEdit(Form)
        self.version.setEnabled(True)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.version.sizePolicy().hasHeightForWidth())
        self.version.setSizePolicy(sizePolicy)
        self.version.setCursor(QtGui.QCursor(QtCore.Qt.ArrowCursor))
        self.version.setReadOnly(True)
        self.version.setObjectName("version")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.version)
        self.upload_time = QtWidgets.QLineEdit(Form)
        self.upload_time.setEnabled(True)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.upload_time.sizePolicy().hasHeightForWidth())
        self.upload_time.setSizePolicy(sizePolicy)
        self.upload_time.setCursor(QtGui.QCursor(QtCore.Qt.ArrowCursor))
        self.upload_time.setReadOnly(True)
        self.upload_time.setObjectName("upload_time")
        self.formLayout.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.upload_time)
        self.label_2 = QtWidgets.QLabel(Form)
        self.label_2.setObjectName("label_2")
        self.formLayout.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.label_2)
        self.label_3 = QtWidgets.QLabel(Form)
        self.label_3.setObjectName("label_3")
        self.formLayout.setWidget(3, QtWidgets.QFormLayout.LabelRole, self.label_3)
        self.assigned_time = QtWidgets.QLineEdit(Form)
        self.assigned_time.setEnabled(True)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.assigned_time.sizePolicy().hasHeightForWidth())
        self.assigned_time.setSizePolicy(sizePolicy)
        self.assigned_time.setCursor(QtGui.QCursor(QtCore.Qt.ArrowCursor))
        self.assigned_time.setReadOnly(True)
        self.assigned_time.setObjectName("assigned_time")
        self.formLayout.setWidget(3, QtWidgets.QFormLayout.FieldRole, self.assigned_time)
        self.label_4 = QtWidgets.QLabel(Form)
        self.label_4.setObjectName("label_4")
        self.formLayout.setWidget(4, QtWidgets.QFormLayout.LabelRole, self.label_4)
        self.assigned_by = QtWidgets.QLineEdit(Form)
        self.assigned_by.setEnabled(True)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.assigned_by.sizePolicy().hasHeightForWidth())
        self.assigned_by.setSizePolicy(sizePolicy)
        self.assigned_by.setCursor(QtGui.QCursor(QtCore.Qt.ArrowCursor))
        self.assigned_by.setReadOnly(True)
        self.assigned_by.setObjectName("assigned_by")
        self.formLayout.setWidget(4, QtWidgets.QFormLayout.FieldRole, self.assigned_by)
        self.verticalLayout_3.addLayout(self.formLayout)
        self.btn_debug = QtWidgets.QPushButton(Form)
        self.btn_debug.setObjectName("btn_debug")
        self.verticalLayout_3.addWidget(self.btn_debug)
        spacerItem = QtWidgets.QSpacerItem(20, 0, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_3.addItem(spacerItem)
        self.horizontalLayout_7 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_7.setSizeConstraint(QtWidgets.QLayout.SetDefaultConstraint)
        self.horizontalLayout_7.setContentsMargins(-1, 0, -1, -1)
        self.horizontalLayout_7.setObjectName("horizontalLayout_7")
        self.last_sync = QtWidgets.QLabel(Form)
        self.last_sync.setObjectName("last_sync")
        self.horizontalLayout_7.addWidget(self.last_sync)
        self.sync_now = QtWidgets.QPushButton(Form)
        self.sync_now.setObjectName("sync_now")
        self.horizontalLayout_7.addWidget(self.sync_now)
        spacerItem1 = QtWidgets.QSpacerItem(20, 5, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_7.addItem(spacerItem1)
        self.verticalLayout_3.addLayout(self.horizontalLayout_7)
        self.horizontalLayout_5 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_5.setObjectName("horizontalLayout_5")
        self.sync_all = QtWidgets.QPushButton(Form)
        self.sync_all.setObjectName("sync_all")
        self.horizontalLayout_5.addWidget(self.sync_all)
        spacerItem2 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_5.addItem(spacerItem2)
        self.verticalLayout_3.addLayout(self.horizontalLayout_5)
        self.horizontalLayout_2.addLayout(self.verticalLayout_3)
        self.verticalLayout_2 = QtWidgets.QVBoxLayout()
        self.verticalLayout_2.setSpacing(5)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        spacerItem3 = QtWidgets.QSpacerItem(20, 0, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_2.addItem(spacerItem3)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.label_5 = QtWidgets.QLabel(Form)
        self.label_5.setObjectName("label_5")
        self.horizontalLayout.addWidget(self.label_5)
        spacerItem4 = QtWidgets.QSpacerItem(5, 5, QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout.addItem(spacerItem4)
        self.description = QtWidgets.QLineEdit(Form)
        self.description.setReadOnly(False)
        self.description.setObjectName("description")
        self.horizontalLayout.addWidget(self.description)
        self.verticalLayout_2.addLayout(self.horizontalLayout)
        self.label = QtWidgets.QLabel(Form)
        self.label.setObjectName("label")
        self.verticalLayout_2.addWidget(self.label)
        self.notes = QtWidgets.QPlainTextEdit(Form)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.notes.sizePolicy().hasHeightForWidth())
        self.notes.setSizePolicy(sizePolicy)
        self.notes.setMinimumSize(QtCore.QSize(0, 100))
        self.notes.setAcceptDrops(False)
        self.notes.setObjectName("notes")
        self.verticalLayout_2.addWidget(self.notes)
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.reset_notes = QtWidgets.QPushButton(Form)
        self.reset_notes.setEnabled(False)
        self.reset_notes.setObjectName("reset_notes")
        self.horizontalLayout_3.addWidget(self.reset_notes)
        spacerItem5 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_3.addItem(spacerItem5)
        self.save_notes = QtWidgets.QPushButton(Form)
        self.save_notes.setEnabled(False)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.save_notes.sizePolicy().hasHeightForWidth())
        self.save_notes.setSizePolicy(sizePolicy)
        self.save_notes.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.save_notes.setObjectName("save_notes")
        self.horizontalLayout_3.addWidget(self.save_notes)
        self.verticalLayout_2.addLayout(self.horizontalLayout_3)
        self.horizontalLayout_2.addLayout(self.verticalLayout_2)
        self.gridLayout.addLayout(self.horizontalLayout_2, 3, 0, 1, 1)
        self.horizontalLayout_4 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_4.setObjectName("horizontalLayout_4")
        self.lbl_login_status = QtWidgets.QLabel(Form)
        self.lbl_login_status.setScaledContents(False)
        self.lbl_login_status.setWordWrap(False)
        self.lbl_login_status.setObjectName("lbl_login_status")
        self.horizontalLayout_4.addWidget(self.lbl_login_status)
        self.login = QtWidgets.QPushButton(Form)
        self.login.setObjectName("login")
        self.horizontalLayout_4.addWidget(self.login)
        self.logout = QtWidgets.QPushButton(Form)
        self.logout.setObjectName("logout")
        self.horizontalLayout_4.addWidget(self.logout)
        spacerItem6 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_4.addItem(spacerItem6)
        spacerItem7 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_4.addItem(spacerItem7)
        self.lbl_serial_number = QtWidgets.QLabel(Form)
        self.lbl_serial_number.setObjectName("lbl_serial_number")
        self.horizontalLayout_4.addWidget(self.lbl_serial_number)
        self.serial_number = QtWidgets.QLineEdit(Form)
        self.serial_number.setReadOnly(True)
        self.serial_number.setObjectName("serial_number")
        self.horizontalLayout_4.addWidget(self.serial_number)
        self.serial_number_from_parameters = QtWidgets.QPushButton(Form)
        self.serial_number_from_parameters.setObjectName("serial_number_from_parameters")
        self.horizontalLayout_4.addWidget(self.serial_number_from_parameters)
        self.lbl_inverter_error = QtWidgets.QLabel(Form)
        self.lbl_inverter_error.setObjectName("lbl_inverter_error")
        self.horizontalLayout_4.addWidget(self.lbl_inverter_error)
        self.gridLayout.addLayout(self.horizontalLayout_4, 0, 0, 1, 1)
        self.files_grid = QtWidgets.QTreeWidget(Form)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(10)
        sizePolicy.setHeightForWidth(self.files_grid.sizePolicy().hasHeightForWidth())
        self.files_grid.setSizePolicy(sizePolicy)
        self.files_grid.setObjectName("files_grid")
        self.files_grid.headerItem().setText(0, "1")
        self.gridLayout.addWidget(self.files_grid, 2, 0, 1, 1)
        self.event_log = QtWidgets.QTextEdit(Form)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.event_log.sizePolicy().hasHeightForWidth())
        self.event_log.setSizePolicy(sizePolicy)
        self.event_log.setReadOnly(True)
        self.event_log.setObjectName("event_log")
        self.gridLayout.addWidget(self.event_log, 4, 0, 1, 1)
        self.gridLayout_2.addLayout(self.gridLayout, 0, 0, 1, 1)

        self.retranslateUi(Form)
        QtCore.QMetaObject.connectSlotsByName(Form)

    def retranslateUi(self, Form):
        _translate = QtCore.QCoreApplication.translate
        Form.setWindowTitle(_translate("Form", "Form"))
        self.label_1.setText(_translate("Form", "Filename"))
        self.label_0.setText(_translate("Form", "Version"))
        self.label_2.setText(_translate("Form", "Upload Time"))
        self.label_3.setText(_translate("Form", "Assigned Time"))
        self.label_4.setText(_translate("Form", "Assigned By"))
        self.btn_debug.setText(_translate("Form", "Debug"))
        self.last_sync.setText(_translate("Form", "Last sync at:"))
        self.sync_now.setText(_translate("Form", "Sync Files Now"))
        self.sync_all.setText(_translate("Form", "Sync All Files for Organization"))
        self.label_5.setText(_translate("Form", "Description"))
        self.label.setText(_translate("Form", "Notes"))
        self.reset_notes.setText(_translate("Form", "Reset Notes"))
        self.save_notes.setText(_translate("Form", "Save Notes"))
        self.lbl_login_status.setText(_translate("Form", "<html><head/><body><p><span style=\" font-weight:600; color:#ff0000;\">Warning: You are not currently logged in to EPC Sync...</span></p></body></html>"))
        self.login.setText(_translate("Form", "Login"))
        self.logout.setText(_translate("Form", "Logout"))
        self.lbl_serial_number.setText(_translate("Form", "Inverter Serial Number"))
        self.serial_number_from_parameters.setText(_translate("Form", "From Parameters"))
        self.lbl_inverter_error.setText(_translate("Form", "<font color=\"red\">(inverter error here)</font>"))
